==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ABooleanBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ABooleanBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1682ce1e91f9e7e3 soot_jimple_parser_node_ABooleanBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TBoolean$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$_init$a54dbc1efa1d7f3a(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TBoolean$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$getBoolean$b3242d902e2d62b7(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$setBoolean$b09da0459350c217(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$getBoolean$b3242d902e2d62b7;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$setBoolean$b09da0459350c217;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TBoolean$object	*(*getBoolean$b3242d902e2d62b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setBoolean$b09da0459350c217)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods	soot_jimple_parser_node_ABooleanBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TBoolean$object	*__5fboolean__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs	soot_jimple_parser_node_ABooleanBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ABooleanBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABooleanBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ABooleanBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ABooleanBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1682ce1e91f9e7e3 soot_jimple_parser_node_ABooleanBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TBoolean$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$_init$a54dbc1efa1d7f3a(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TBoolean$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$getBoolean$b3242d902e2d62b7(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$setBoolean$b09da0459350c217(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$getBoolean$b3242d902e2d62b7;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$setBoolean$b09da0459350c217;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TBoolean$object	*(*getBoolean$b3242d902e2d62b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setBoolean$b09da0459350c217)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vmethods	soot_jimple_parser_node_ABooleanBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TBoolean$object	*__5fboolean__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_refs	soot_jimple_parser_node_ABooleanBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ABooleanBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABooleanBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABooleanBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABooleanBaseTypeNoName_H_ */
